library(DPpackage)
library(lattice)
data<-read.table("/home/jovyan/data/P7-N1_N6.mcf.plot") ## input file: mcf
y<-cbind(data$P7U1,data$P7U6)
xxlim <- seq(-1,3,0.17)
yylim <- seq(-1,3,0.17)
left <- matrix(0,nrow=nrow(y),ncol=2)
right <- matrix(0,nrow=nrow(y),ncol=2)
for(i in 1:nrow(y))
{
left[i,1] <- NA
right[i,1] <- NA
if(y[i,1] < xxlim[1]) right[i,1] <- xxlim[1]
for(j in 1:length(xxlim))
{
if(y[i,1] >= xxlim[j]) left[i,1] <- xxlim[j]
if(y[i,1] >= xxlim[j]) right[i,1] <- xxlim[j+1]
}
left[i,2] <- NA
right[i,2] <- NA
if(y[i,2] < yylim[1]) right[i,2] <- yylim[1]
for(j in 1:length(yylim))
{
if(y[i,2] >= yylim[j]) left[i,2] <- yylim[j]
if(y[i,2] >= yylim[j]) right[i,2] <- yylim[j+1]
}
}
# Prior information
s2 <- matrix(c(1,0,0,1),ncol=2)
m2 <- c(1,1)
psiinv2 <- diag(c(1/10000,1),2)
prior <- list(alpha=1,nu1=4,nu2=4,s2=s2,m2=m2,psiinv2=psiinv2,tau1=0.01,tau2=0.01)

state <- NULL
# MCMC parameters
nburn <- 2000
nsave <- 2000
nskip <- 3
ndisplay <- 2000
mcmc <- list(nburn=nburn,nsave=nsave,nskip=nskip,ndisplay=ndisplay)
# Fitting the model
set.seed(1234)
fit1 <- DPMdencens(left=left,right=right,ngrid=300,
prior=prior,mcmc=mcmc,state=state,status=TRUE)
par(xaxs="r")

## level plot
colours=colorRampPalette(c("white","red"))
#colours = c("grey90",terrain.colors(5))
#colours=c("dodgerblue","orange","dodgerblue","orange","dodgerblue","orange")
levelplot(fit1$fbiv[[1]],row.values=fit1$grid[,1],column.values=fit1$grid[,2],
xlim=c(-0.1,1.5),ylim=c(-0.1,1.5),col.regions=colours,colorkey=F,contour=F,
xlab="P7U1",ylab="P7U6",panel = function(...) {panel.levelplot(...)
panel.abline(h = c(0,1),lty=2)
panel.abline(v = c(0,1),lty=2)
panel.points(data,col="blue",pch=19,cex=0.2)})

state <- fit1$state$ss  ##cluster information
data_state <- cbind(data,state)
write.table(data_state,file="/home/jovyan/data/P7U1_U6.mcf.cluster.txt",quote=F,sep="\t")